@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 0.0900;
+our $VERSION = 0.1000;
 
 my %ref;
 
@@ -414,6 +414,30 @@ sub GetEnvelope3D {
     return $envelope;
 }
 
+sub MakeValid {
+    my ($self, %options) = @_;
+    my $o = 0;
+    for my $key (keys %options) {
+        $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$options{$key}");
+    }
+    my $p;
+    if ($o) {
+        $p = Geo::GDAL::FFI::OGR_G_MakeValidEx($$self, $o);
+        Geo::GDAL::FFI::CSLDestroy($o);
+    } else {
+        $p = Geo::GDAL::FFI::OGR_G_MakeValid($$self);
+    }
+    confess Geo::GDAL::FFI::error_msg() unless $p;
+    return bless \$p, 'Geo::GDAL::FFI::Geometry';
+}
+
+sub Normalize {
+    my ($self) = @_;
+    my $g = Geo::GDAL::FFI::OGR_G_Normalize($$self);
+    confess Geo::GDAL::FFI::error_msg() unless $g;
+    return bless \$g, 'Geo::GDAL::FFI::Geometry';
+}
+
 
 1;
 
@@ -552,14 +576,14 @@ Returns the geometry as WKT. $variant is optional (default is 'ISO').
 
 Alias to ExportToWKT.
 
-=head2 ExportToGML($options)
+=head2 ExportToGML(%options)
 
  my $gml = $geom->ExportToGML(%options);
 
 Returns the geometry as GML string. %options may contain options as
 described in GDAL documentation.
 
-=head2 ExportToJSON($options)
+=head2 ExportToJSON(%options)
 
  my $json = $geom->ExportToJSON(%options);
 
@@ -626,6 +650,22 @@ Returns a four element array reference containing
 Returns a six element array reference containing
 [Xmin, Xmax, Ymin, Ymax, Zmin, Zmax].
 
+=head2 MakeValid(%options)
+
+ my $valid_geom = $geom->MakeValid(%options);
+
+Attempts to make an invalid geometry valid and returns that. %options
+may contain options as described in GDAL documentation.
+
+Requires GDAL version >= 3.0
+
+=head2 Normalize()
+
+ my $normalized_geom = $geom->Normalize();
+
+Attempts to bring geometry into normalized/canonical form.
+
+Requires GDAL version >= 3.3
 
 =head1 LICENSE
 
